featureflags.models package
===========================

Submodules
----------

featureflags.models.authentication\_request module
--------------------------------------------------

.. automodule:: featureflags.models.authentication_request
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.models.authentication\_request\_target module
----------------------------------------------------------

.. automodule:: featureflags.models.authentication_request_target
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.models.authentication\_request\_target\_attributes module
----------------------------------------------------------------------

.. automodule:: featureflags.models.authentication_request_target_attributes
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.models.authentication\_response module
---------------------------------------------------

.. automodule:: featureflags.models.authentication_response
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.models.error module
--------------------------------

.. automodule:: featureflags.models.error
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.models.key\_value module
-------------------------------------

.. automodule:: featureflags.models.key_value
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.models.message module
----------------------------------

.. automodule:: featureflags.models.message
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.models.metrics module
----------------------------------

.. automodule:: featureflags.models.metrics
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.models.metrics\_data module
----------------------------------------

.. automodule:: featureflags.models.metrics_data
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.models.metrics\_data\_metrics\_type module
-------------------------------------------------------

.. automodule:: featureflags.models.metrics_data_metrics_type
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.models.pagination module
-------------------------------------

.. automodule:: featureflags.models.pagination
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.models.target\_data module
---------------------------------------

.. automodule:: featureflags.models.target_data
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.models.unset module
--------------------------------

.. automodule:: featureflags.models.unset
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: featureflags.models
   :members:
   :undoc-members:
   :show-inheritance:
